import { N8AOPostPass } from 'n8ao';
import * as i0 from '@angular/core';
import { input, inject, computed, effect, Component, CUSTOM_ELEMENTS_SCHEMA, ChangeDetectionStrategy } from '@angular/core';
import { pick, applyProps, NgtArgs } from 'angular-three';
import { NgtpEffectComposer } from 'angular-three-postprocessing';
import { mergeInputs } from 'ngxtension/inject-inputs';

// @ts-expect-error - n8ao is not typed
const defaultOptions = {
    aoSamples: 16,
    aoRadius: 5.0,
    aoTones: 0.0,
    denoiseSamples: 8,
    denoiseRadius: 12,
    distanceFalloff: 1.0,
    intensity: 5,
    denoiseIterations: 2.0,
    renderMode: 0,
    biasOffset: 0.0,
    biasMultiplier: 0.0,
    color: 'black',
    gammaCorrection: true,
    logarithmicDepthBuffer: false,
    screenSpaceRadius: false,
    halfRes: false,
    depthAwareUpsampling: true,
    colorMultiply: true,
    transparencyAware: false,
    accumulate: false,
};
class NgtpN8AO {
    constructor() {
        this.options = input(defaultOptions, { transform: mergeInputs(defaultOptions) });
        this.quality = pick(this.options, 'quality');
        this.effectComposer = inject(NgtpEffectComposer);
        this.effect = computed(() => {
            const [scene, camera] = [this.effectComposer.scene(), this.effectComposer.camera()];
            return new N8AOPostPass(scene, camera);
        });
        effect(() => {
            const n8aoEffect = this.effect();
            if (!n8aoEffect)
                return;
            const { quality: _, ...configurations } = this.options();
            applyProps(n8aoEffect.configuration, configurations);
        });
        effect(() => {
            this.setQualityEffect();
        });
        effect((onCleanup) => {
            const effect = this.effect();
            onCleanup(() => effect.dispose());
        });
    }
    setQualityEffect() {
        const effect = this.effect();
        if (!effect)
            return;
        const quality = this.quality();
        if (!quality)
            return;
        const titleCaseQuality = quality.charAt(0).toUpperCase() + quality.slice(1);
        effect.setQuality(titleCaseQuality);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: NgtpN8AO, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.1.6", type: NgtpN8AO, isStandalone: true, selector: "ngtp-n8ao", inputs: { options: { classPropertyName: "options", publicName: "options", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0, template: `
		<ngt-primitive *args="[effect()]" />
	`, isInline: true, dependencies: [{ kind: "directive", type: NgtArgs, selector: "ng-template[args]", inputs: ["args"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.6", ngImport: i0, type: NgtpN8AO, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngtp-n8ao',
                    template: `
		<ngt-primitive *args="[effect()]" />
	`,
                    imports: [NgtArgs],
                    schemas: [CUSTOM_ELEMENTS_SCHEMA],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { NgtpN8AO };
//# sourceMappingURL=angular-three-postprocessing-n8ao.mjs.map
